<?xml version="1.0" ?><!DOCTYPE TS><TS language="cs" version="2.0">
<context>
    <name>Badges</name>
    <message>
        <location filename="../qml/pages/Badges.qml" line="18"/>
        <source>BADGES</source>
        <translation>ODZNAKY</translation>
    </message>
</context>
<context>
    <name>Checkin</name>
    <message>
        <location filename="../qml/pages/Checkin.qml" line="18"/>
        <source>CHECK-IN DETAILS</source>
        <translation>DETAILY CHECK-INU</translation>
    </message>
    <message>
        <location filename="../qml/pages/Checkin.qml" line="222"/>
        <source>TOTAL POINTS</source>
        <translation>VŠECHNY BODY</translation>
    </message>
    <message>
        <location filename="../qml/pages/Checkin.qml" line="260"/>
        <source>EARNED BADGES</source>
        <translation>ZÍSKANÉ ODZNAKY</translation>
    </message>
    <message>
        <location filename="../qml/pages/Checkin.qml" line="282"/>
        <source>COMMENTS</source>
        <translation>KOMENTÁŘE</translation>
    </message>
</context>
<context>
    <name>CheckinDialog</name>
    <message>
        <location filename="../qml/pages/CheckinDialog.qml" line="22"/>
        <source>NEW CHECK-IN</source>
        <translation>NOVÝ CHECK-IN</translation>
    </message>
    <message>
        <location filename="../qml/pages/CheckinDialog.qml" line="48"/>
        <source>CHECK IN</source>
        <translation>CHECK IN</translation>
    </message>
    <message>
        <location filename="../qml/pages/CheckinDialog.qml" line="57"/>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <location filename="../qml/pages/CheckinDialog.qml" line="100"/>
        <source>Whats on your mind?</source>
        <translation>Co se vám honí hlavou?</translation>
    </message>
    <message>
        <location filename="../qml/pages/CheckinDialog.qml" line="129"/>
        <source>Sharing options</source>
        <translation>Možnosti sdílení</translation>
    </message>
    <message>
        <location filename="../qml/pages/CheckinDialog.qml" line="133"/>
        <source>Share with Friends</source>
        <translation>Sdílet s Přáteli</translation>
    </message>
    <message>
        <location filename="../qml/pages/CheckinDialog.qml" line="141"/>
        <source>Post to Facebook</source>
        <translation>Sdílet na Facebooku</translation>
    </message>
    <message>
        <location filename="../qml/pages/CheckinDialog.qml" line="149"/>
        <source>Post to Twitter</source>
        <translation>Sdílet na Twitteru</translation>
    </message>
</context>
<context>
    <name>CheckinHistory</name>
    <message>
        <location filename="../qml/pages/CheckinHistory.qml" line="24"/>
        <source>CHECK-IN HISTORY</source>
        <translation>HISTORIE CHECK-INŮ</translation>
    </message>
    <message>
        <location filename="../qml/pages/CheckinHistory.qml" line="64"/>
        <source>Load More</source>
        <translation>Načíst další</translation>
    </message>
</context>
<context>
    <name>CommentDialog</name>
    <message>
        <location filename="../qml/components/CommentDialog.qml" line="26"/>
        <source>What is on your mind?</source>
        <translation>Co se vám honí hlavou?</translation>
    </message>
    <message>
        <location filename="../qml/components/CommentDialog.qml" line="38"/>
        <source>New awesome comment</source>
        <translation>Nový skvělý komentář</translation>
    </message>
    <message>
        <location filename="../qml/components/CommentDialog.qml" line="69"/>
        <source>Comment!</source>
        <translation>Okomentovat!</translation>
    </message>
    <message>
        <location filename="../qml/components/CommentDialog.qml" line="77"/>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
</context>
<context>
    <name>DebugSubmit</name>
    <message>
        <location filename="../qml/pages/DebugSubmit.qml" line="18"/>
        <source>DEBUG SUBMIT</source>
        <translation>POSLAT CHYBOVÉ HLÁŠENÍ</translation>
    </message>
    <message>
        <location filename="../qml/pages/DebugSubmit.qml" line="34"/>
        <source>Thank you for submit!&lt;br&gt;This will be implemented soon!</source>
        <translation>Děkujeme za zaslání&lt;br&gt;Brzy to bude napraveno!</translation>
    </message>
    <message>
        <location filename="../qml/pages/DebugSubmit.qml" line="53"/>
        <source>SUBMIT</source>
        <translation>ZASLAT</translation>
    </message>
    <message>
        <location filename="../qml/pages/DebugSubmit.qml" line="61"/>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <location filename="../qml/pages/DebugSubmit.qml" line="92"/>
        <source>You can help me with Nelisquare development by submitting debug info.

The following information are going to be submitted:</source>
        <translation>Můžete mi pomoci s vývojem Nelisquare zasláním informací o chybách.⏎
⏎
Následující informace budou odeslány:</translation>
    </message>
</context>
<context>
    <name>DebugWidget</name>
    <message>
        <location filename="../qml/components/DebugWidget.qml" line="14"/>
        <source>Unknown %1 event!</source>
        <translation>Neznámá událost %1 !</translation>
    </message>
    <message>
        <location filename="../qml/components/DebugWidget.qml" line="47"/>
        <source>This event type is unknown.
You can help with resolution.</source>
        <translation>Neznámy typ události.⏎
Můžete pomoci s řešením.</translation>
    </message>
</context>
<context>
    <name>FriendsFeed</name>
    <message>
        <location filename="../qml/pages/FriendsFeed.qml" line="43"/>
        <source>FRIENDS FEED</source>
        <translation>KANÁL PŘÁTEL</translation>
    </message>
    <message>
        <location filename="../qml/pages/FriendsFeed.qml" line="229"/>
        <source>RECENT</source>
        <translation>NEDÁVNÉ</translation>
    </message>
    <message>
        <location filename="../qml/pages/FriendsFeed.qml" line="242"/>
        <source>NEARBY</source>
        <translation>POBLÍŽ</translation>
    </message>
    <message>
        <location filename="../qml/pages/FriendsFeed.qml" line="263"/>
        <source>Load More</source>
        <translation>Načíst další</translation>
    </message>
    <message>
        <location filename="../qml/pages/FriendsFeed.qml" line="410"/>
        <source>Sorry, Pages are not supported yet :(</source>
        <translation>Bohužel, Stránky ještě nejsou podporované :(</translation>
    </message>
    <message>
        <location filename="../qml/pages/FriendsFeed.qml" line="480"/>
        <source>Sorry, no lists support yet :(</source>
        <translation>Bohužel, seznamy ještě nejsou podporované :(</translation>
    </message>
</context>
<context>
    <name>LeaderBoard</name>
    <message>
        <location filename="../qml/pages/LeaderBoard.qml" line="19"/>
        <source>YOU ARE #%1</source>
        <translation>VY JSTE #%1</translation>
    </message>
    <message>
        <location filename="../qml/pages/LeaderBoard.qml" line="63"/>
        <source>&lt;b&gt;%1 points&lt;/b&gt; %2 checkins</source>
        <translation>&lt;b&gt;%1 bodů&lt;/b&gt; %2 checkinů</translation>
    </message>
</context>
<context>
    <name>LikeBox</name>
    <message>
        <location filename="../qml/components/LikeBox.qml" line="33"/>
        <source>USER LIKES</source>
        <translation>LÍBÍ SE MI UŽIVATELŮ</translation>
    </message>
</context>
<context>
    <name>ListViewEx</name>
    <message>
        <location filename="../qml/components/ListViewEx.qml" line="9"/>
        <source>Pull and hold to refresh...</source>
        <translation>Táhněte a držte pro aktualizaci...</translation>
    </message>
    <message>
        <location filename="../qml/components/ListViewEx.qml" line="10"/>
        <source>Release to refresh...</source>
        <translation>Pusťte pro aktualizaci...</translation>
    </message>
</context>
<context>
    <name>Login24sq</name>
    <message>
        <location filename="../qml/pages/Login24sq.qml" line="15"/>
        <source>Sign In to Foursquare</source>
        <translation>Přihlásit se do Foursquare</translation>
    </message>
    <message>
        <location filename="../qml/pages/Login24sq.qml" line="41"/>
        <source>Exit</source>
        <translation>Ukončit</translation>
    </message>
    <message>
        <location filename="../qml/pages/Login24sq.qml" line="59"/>
        <source>Error connecting to Foursquare site</source>
        <translation>Nastala chyba při připojování k Foursquare</translation>
    </message>
</context>
<context>
    <name>Mayorships</name>
    <message>
        <location filename="../qml/pages/Mayorships.qml" line="19"/>
        <source>MAYORSHIPS</source>
        <translation>KDE JSEM STAROSTOU</translation>
    </message>
</context>
<context>
    <name>NotificationDialog</name>
    <message>
        <location filename="../qml/components/NotificationDialog.qml" line="36"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>Notifications</name>
    <message>
        <location filename="../qml/pages/Notifications.qml" line="24"/>
        <source>NOTIFICATIONS</source>
        <translation>UPOZORNĚNÍ</translation>
    </message>
    <message>
        <location filename="../qml/pages/Notifications.qml" line="51"/>
        <source>Mark all as read</source>
        <translation>Označit vše jako přečtené</translation>
    </message>
    <message>
        <location filename="../qml/pages/Notifications.qml" line="61"/>
        <source>Settings</source>
        <translation>Nastavení</translation>
    </message>
</context>
<context>
    <name>PageWrapper</name>
    <message>
        <location filename="../qml/components/PageWrapper.qml" line="101"/>
        <source>Check updates</source>
        <translation>Zkontrolovat nové verze</translation>
    </message>
    <message>
        <location filename="../qml/components/PageWrapper.qml" line="107"/>
        <source>Settings</source>
        <translation>Nastavení</translation>
    </message>
    <message>
        <location filename="../qml/components/PageWrapper.qml" line="113"/>
        <source>Exit</source>
        <translation>Ukončit</translation>
    </message>
</context>
<context>
    <name>Photo</name>
    <message>
        <location filename="../qml/pages/Photo.qml" line="20"/>
        <source>PHOTO</source>
        <translation>FOTKA</translation>
    </message>
    <message>
        <location filename="../qml/pages/Photo.qml" line="45"/>
        <source>You cannot save image until download is finished</source>
        <translation>Obrázek lze uložit až po dokončení stahování</translation>
    </message>
    <message>
        <location filename="../qml/pages/Photo.qml" line="49"/>
        <source>Image saved to %1</source>
        <translation>Obrázek uložen do %1</translation>
    </message>
    <message>
        <location filename="../qml/pages/Photo.qml" line="51"/>
        <source>Failed to save image</source>
        <translation>Ukládání se nezdařilo</translation>
    </message>
</context>
<context>
    <name>PhotoAdd</name>
    <message>
        <location filename="../qml/pages/PhotoAdd.qml" line="19"/>
        <source>Select photo for upload</source>
        <translation>Vyberte obrázek k nahrání</translation>
    </message>
    <message>
        <location filename="../qml/pages/PhotoAdd.qml" line="60"/>
        <source>Error uploading photo!&lt;br&gt;Photo size should be less than %1KB</source>
        <translation>Chyba v nahrávání fotografie&lt;br&gt;Velikost fotografie by měla být menší než %1KB</translation>
    </message>
</context>
<context>
    <name>PhotoShareDialog</name>
    <message>
        <location filename="../qml/pages/PhotoShareDialog.qml" line="20"/>
        <source>PHOTO UPLOAD</source>
        <translation>NAHRÁNÍ FOTEK</translation>
    </message>
    <message>
        <location filename="../qml/pages/PhotoShareDialog.qml" line="36"/>
        <source>UPLOAD</source>
        <translation>NAHRÁVÁNÍ</translation>
    </message>
    <message>
        <location filename="../qml/pages/PhotoShareDialog.qml" line="91"/>
        <source>Sharing options</source>
        <translation>Možnosti sdílení</translation>
    </message>
    <message>
        <location filename="../qml/pages/PhotoShareDialog.qml" line="95"/>
        <source>Public</source>
        <translation>Veřejné</translation>
    </message>
    <message>
        <location filename="../qml/pages/PhotoShareDialog.qml" line="102"/>
        <source>Post to Facebook</source>
        <translation>Sdílet na Facebooku</translation>
    </message>
    <message>
        <location filename="../qml/pages/PhotoShareDialog.qml" line="109"/>
        <source>Post to Twitter</source>
        <translation>Sdílet na Twitteru</translation>
    </message>
    <message>
        <location filename="../qml/pages/PhotoShareDialog.qml" line="48"/>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
</context>
<context>
    <name>PhotosBox</name>
    <message>
        <location filename="../qml/components/PhotosBox.qml" line="8"/>
        <source>PHOTOS</source>
        <translation>FOTKY</translation>
    </message>
</context>
<context>
    <name>PhotosGallery</name>
    <message>
        <location filename="../qml/pages/PhotosGallery.qml" line="13"/>
        <source>VENUE PHOTOS</source>
        <translation>FOTKY PODNIKU</translation>
    </message>
</context>
<context>
    <name>SettingSlider</name>
    <message>
        <location filename="../qml/components/SettingSlider.qml" line="50"/>
        <source>Off</source>
        <translation>Vypnuto</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <location filename="../qml/pages/Settings.qml" line="13"/>
        <source>updating...</source>
        <translation>aktualizuji...</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="21"/>
        <source>SETTINGS</source>
        <translation>NASTAVENÍ</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="55"/>
        <source>2012-2013 Basil Semuonov</source>
        <translation>2012-2013 Basil Semuonov</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="56"/>
        <source>Idea by Tommi Laukkanen</source>
        <translation>Napád od Tommiho Laukkanena</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="57"/>
        <source>Shout out to @knobtviker</source>
        <translation>Ozvěte se na @knobtviker</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="58"/>
        <source>Design by Kim Venetvirta</source>
        <translation>Design od Kima Venetvirta</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="59"/>
        <source>If any problems, tweet @basil_s</source>
        <translation>Při potížích tweetujte na @basil_s</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="60"/>
        <source>Version</source>
        <translation>Verze</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="62"/>
        <source>Build</source>
        <translation>Sestavení</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="64"/>
        <source>Powered by Foursquare</source>
        <translation>Poháněno Foursquare</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="66"/>
        <source>Close</source>
        <translation>Zavřít</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="72"/>
        <location filename="../qml/pages/Settings.qml" line="117"/>
        <source>Reset settings</source>
        <translation>Obnovit nastavení</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="73"/>
        <source>This action will erase all data including auth token, application settings and cache.</source>
        <translation>Tato volba vymaže veškerá data, včetně přihlašovací tokenu, nastavení a cache</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="74"/>
        <source>Yes, clear the data</source>
        <translation>Ano, vymazat data</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="75"/>
        <source>No, thanks</source>
        <translation>Ne, děkuji</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="83"/>
        <source>Language</source>
        <translation>Jazyk</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="111"/>
        <source>Notifications</source>
        <translation>Upozornění</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="163"/>
        <source>UPDATES CHECK</source>
        <translation>KONTROLA NOVÉ VERZE</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="188"/>
        <source>None</source>
        <translation>Žádná</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="194"/>
        <source>Stable</source>
        <translation>Stabilní</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="199"/>
        <source>Beta</source>
        <translation>Beta</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="205"/>
        <source>Alpha</source>
        <translation>Alfa</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="211"/>
        <source>INTERVALS</source>
        <translation>INTERVALY</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="215"/>
        <source>GPS Unlock timeout</source>
        <translation>Časový limit odemčení GPS</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="216"/>
        <source>Instant</source>
        <translation>Ihned</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="216"/>
        <source>%1 secs(s)</source>
        <translation>%1 s</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="216"/>
        <location filename="../qml/pages/Settings.qml" line="225"/>
        <source>Disabled</source>
        <translation>Vypnuto</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="224"/>
        <source>Feed autoupdate time</source>
        <translation>Čas automatické aktualizace kanálu</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="225"/>
        <source>Off</source>
        <translation>Vypnuto</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="225"/>
        <source>%1 min(s)</source>
        <translation>%1 min</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="233"/>
        <source>PERMISSIONS</source>
        <translation>OPRÁVNĚNÍ</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="236"/>
        <source>Allow use of Location Data</source>
        <translation>Povolit použití lokalizace</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="244"/>
        <source>Always run in background</source>
        <translation>Vždy nechat běžet na pozadí</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="252"/>
        <source>Enable notifications</source>
        <translation>Povolit upozornění</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="260"/>
        <source>Feed at Home screen</source>
        <translation>Kanál na Domovské stránce</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="268"/>
        <source>Push notifications</source>
        <translation>Přímá upozornění</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="319"/>
        <source>COLOR THEME</source>
        <translation>BAREVNÉ TÉMA</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="338"/>
        <source>Light</source>
        <translation>Světlé</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="347"/>
        <source>Dark</source>
        <translation>Tmavé</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="356"/>
        <source>SCREEN ORIENTATION</source>
        <translation>ROTACE DISPLEJE</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="378"/>
        <source>Auto</source>
        <translation>Automaticky</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="384"/>
        <source>Landscape</source>
        <translation>Na šířku</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="389"/>
        <source>Portrait</source>
        <translation>Na výšku</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="395"/>
        <source>STARTUP PAGE</source>
        <translation>STRÁNKA PŘI SPUŠTĚNÍ</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="417"/>
        <source>Feed</source>
        <translation>Kanál</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="423"/>
        <source>Venues</source>
        <translation>Podniky</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="428"/>
        <source>Self</source>
        <translation>Vlastní</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="434"/>
        <source>LANGUAGE</source>
        <translation>JAZYK</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="445"/>
        <source>MAP PROVIDER</source>
        <translation>POSKYTOVATEL MAP</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="468"/>
        <source>Nokia</source>
        <translation>Nokia</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="474"/>
        <source>Google</source>
        <translation>Google</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="479"/>
        <source>OSM</source>
        <translation>OSM</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="497"/>
        <source>IMAGE LOADING</source>
        <translation>NAČÍTÁNÍ OBRÁZKŮ</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="516"/>
        <source>All</source>
        <translation>Vše</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="521"/>
        <source>Cached</source>
        <translation>Načtené</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="527"/>
        <source>INTEGRATION WITH APPS</source>
        <translation>INTEGRACE S APLIKACEMI</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="533"/>
        <source>Download MOLO.ME</source>
        <translation>Stáhnout MOLO.ME</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="552"/>
        <source>MOLO.ME Photos</source>
        <translation>Fotografie MOLO.ME</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="572"/>
        <source>APPLICATION CACHE</source>
        <translation>CACHE APLIKACE</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="580"/>
        <source>Clear</source>
        <translation>Vymazat</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="592"/>
        <source>Size: %1</source>
        <translation>Velikost: %1</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="598"/>
        <source>UI</source>
        <translation>UI</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="601"/>
        <source>Reload UI</source>
        <translation>Znovu nahrát UI</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="607"/>
        <source>AUTHENTICATION</source>
        <translation>PŘIHLÁŠENÍ</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="610"/>
        <source>Reset authentication</source>
        <translation>Obnovit přihlášení</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="631"/>
        <source>ACCESS RATE LIMIT</source>
        <translation>LIMIT PŘÍSTUPŮ</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="637"/>
        <source>API requests available: %1 / %2</source>
        <translation>Zbývající API požadavky: %1 / %2</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="643"/>
        <source>You are low on X-RATE requests</source>
        <translation>Zbývá málo X-RATE požadavkůů</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="648"/>
        <source>DEBUG</source>
        <translation>CHYBOVÁ HLÁŠENÍ</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="651"/>
        <source>Enable debug</source>
        <translation>Povolit chybová hlášení</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="665"/>
        <source>Options will be available soon</source>
        <translation>Možnosti budou brzy dostupné</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="680"/>
        <source>General</source>
        <translation>Obecné</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="681"/>
        <source>Theme</source>
        <translation>Vzhled</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="682"/>
        <source>Service</source>
        <translation>Služby</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="683"/>
        <source>Debug</source>
        <translation>Chyby</translation>
    </message>
</context>
<context>
    <name>SpecialsList</name>
    <message>
        <location filename="../qml/components/SpecialsList.qml" line="13"/>
        <source>VENUE SPECIALS</source>
        <translation>SPECIALITY PODNIKU</translation>
    </message>
    <message>
        <location filename="../qml/components/SpecialsList.qml" line="31"/>
        <source>Unlocked!</source>
        <translation>Odemčeno!</translation>
    </message>
</context>
<context>
    <name>TipDialog</name>
    <message>
        <location filename="../qml/components/TipDialog.qml" line="40"/>
        <source>Write some cool tip here</source>
        <translation>Napište nám sem váš tip</translation>
    </message>
    <message>
        <location filename="../qml/components/TipDialog.qml" line="71"/>
        <source>ADD</source>
        <translation>PŘIDAT</translation>
    </message>
    <message>
        <location filename="../qml/components/TipDialog.qml" line="79"/>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
</context>
<context>
    <name>TipPage</name>
    <message>
        <location filename="../qml/pages/TipPage.qml" line="22"/>
        <source>Usefull tip</source>
        <translation>Užitečný tip</translation>
    </message>
    <message>
        <location filename="../qml/pages/TipPage.qml" line="148"/>
        <source>TIP PHOTO</source>
        <translation>TIP NA FOTO</translation>
    </message>
    <message>
        <location filename="../qml/pages/TipPage.qml" line="170"/>
        <source>Save tip</source>
        <translation>Uložit tip</translation>
    </message>
    <message>
        <location filename="../qml/pages/TipPage.qml" line="178"/>
        <source>Mark as done</source>
        <translation>Označit jako hotové</translation>
    </message>
</context>
<context>
    <name>TipsList</name>
    <message>
        <location filename="../qml/pages/TipsList.qml" line="18"/>
        <source>TIPS LIST</source>
        <translation>SEZNAM TIPŮ</translation>
    </message>
</context>
<context>
    <name>UpdateDialog</name>
    <message>
        <location filename="../qml/components/UpdateDialog.qml" line="12"/>
        <source>New update available</source>
        <translation>Dostupná nová verze</translation>
    </message>
    <message>
        <location filename="../qml/components/UpdateDialog.qml" line="13"/>
        <source>Version: %1&lt;br&gt;Type: %2&lt;br&gt;Build: %3&lt;br&gt;&lt;br&gt;Changelog: &lt;br&gt;%4</source>
        <translation>Verze: %1&lt;br&gt;Typ: %2&lt;br&gt;Sestavení: %3&lt;br&gt;&lt;br&gt;Seznam změn: &lt;br&gt;%4</translation>
    </message>
    <message>
        <location filename="../qml/components/UpdateDialog.qml" line="19"/>
        <source>Update!</source>
        <translation>Aktualizovat!</translation>
    </message>
    <message>
        <location filename="../qml/components/UpdateDialog.qml" line="20"/>
        <source>No, thanks</source>
        <translation>Ne, děkuji</translation>
    </message>
</context>
<context>
    <name>User</name>
    <message>
        <location filename="../qml/pages/User.qml" line="60"/>
        <source>USER DETAILS</source>
        <translation>DETAILY UŽIVATELE</translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="69"/>
        <source>Change avatar</source>
        <translation>Změnit avatar</translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="77"/>
        <source>User lists</source>
        <translation>Uživatelské seznamy</translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="85"/>
        <source>Settings</source>
        <translation>Nastavení</translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="91"/>
        <source>Exit</source>
        <translation>Ukončit</translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="303"/>
        <source>Add Friend</source>
        <translation>Přidat Přítele</translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="315"/>
        <source>Approve Friend</source>
        <translation>Potvrdit Přítele</translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="322"/>
        <source>Deny friend</source>
        <translation>Odmítnout Přítele</translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="334"/>
        <source>Remove Friend</source>
        <translation>Odstranit Přítele</translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="347"/>
        <source>&lt;b&gt;SCORES&lt;/b&gt; (LAST 7 DAYS)</source>
        <translation>&lt;b&gt;SKÓRE&lt;/b&gt; (POSLEDNÍ TÝDEN)</translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="352"/>
        <source>BEST SCORE</source>
        <translation>NEJLEPŠÍ SKÓRE</translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="410"/>
        <source>Badges</source>
        <translation>Odznaky</translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="445"/>
        <source>Checkins</source>
        <translation>Checkiny</translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="480"/>
        <source>Mayorships</source>
        <translation>Starostou</translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="515"/>
        <source>Friends</source>
        <translation>Přátelé</translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="550"/>
        <source>Photos</source>
        <translation>Fotky</translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="586"/>
        <source>Tips</source>
        <translation>Tipy</translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="602"/>
        <source>YOU ARE #%1</source>
        <translation>VY JSTE #%1</translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="627"/>
        <source>&lt;b&gt;%1 points&lt;/b&gt; %2 checkins</source>
        <translation>&lt;b&gt;%1 bodů&lt;/b&gt; %2 checkinů</translation>
    </message>
</context>
<context>
    <name>UsersList</name>
    <message>
        <location filename="../qml/pages/UsersList.qml" line="21"/>
        <source>Loading...</source>
        <translation>Načítání...</translation>
    </message>
    <message>
        <location filename="../qml/pages/UsersList.qml" line="30"/>
        <source>USER FRIENDS</source>
        <translation>PŘÁTELÉ UŽIVATELE</translation>
    </message>
    <message>
        <location filename="../qml/pages/UsersList.qml" line="33"/>
        <source>LIKERS LIST</source>
        <translation>KDO DAL LÍBÍ SE MI</translation>
    </message>
</context>
<context>
    <name>Venue</name>
    <message>
        <location filename="../qml/pages/Venue.qml" line="142"/>
        <source>VENUE PHOTOS</source>
        <translation>FOTKY PODNIKU</translation>
    </message>
    <message>
        <location filename="../qml/pages/Venue.qml" line="250"/>
        <source>CHECK-IN HERE!</source>
        <translation>CHECK-IN ZDE!</translation>
    </message>
    <message>
        <location filename="../qml/pages/Venue.qml" line="272"/>
        <source>Venue doesn&apos;t have mayor yet!</source>
        <translation>Tento podnik ještě nemá starostu!</translation>
    </message>
    <message>
        <location filename="../qml/pages/Venue.qml" line="273"/>
        <source>is the mayor.</source>
        <translation>je starostou.</translation>
    </message>
    <message>
        <location filename="../qml/pages/Venue.qml" line="273"/>
        <source>It could be you!</source>
        <translation>Můžete to být vy!</translation>
    </message>
    <message>
        <location filename="../qml/pages/Venue.qml" line="274"/>
        <source>%1 checkins</source>
        <translation>%1 checkinů</translation>
    </message>
    <message>
        <location filename="../qml/pages/Venue.qml" line="317"/>
        <source>BEST TIPS</source>
        <translation>NEJLEPŠÍ TIPY</translation>
    </message>
</context>
<context>
    <name>VenueAdd</name>
    <message>
        <location filename="../qml/pages/VenueAdd.qml" line="32"/>
        <source>ADD NEW VENUE</source>
        <translation>PŘIDAT NOVÝ PODNIK</translation>
    </message>
    <message>
        <location filename="../qml/pages/VenueAdd.qml" line="74"/>
        <source>Select category</source>
        <translation>Vybrat kategorii</translation>
    </message>
    <message>
        <location filename="../qml/pages/VenueAdd.qml" line="94"/>
        <source>Select sub-category</source>
        <translation>Vybrat podkategorii</translation>
    </message>
    <message>
        <location filename="../qml/pages/VenueAdd.qml" line="131"/>
        <source>VENUE NAME</source>
        <translation>NÁZEV PODNIKU</translation>
    </message>
    <message>
        <location filename="../qml/pages/VenueAdd.qml" line="136"/>
        <source>Venue name required</source>
        <translation>Je nutné vyplnit jméno podniku </translation>
    </message>
    <message>
        <location filename="../qml/pages/VenueAdd.qml" line="145"/>
        <source>VENUE ADDRESS</source>
        <translation>ADRESA PODNIKU</translation>
    </message>
    <message>
        <location filename="../qml/pages/VenueAdd.qml" line="150"/>
        <source>Street address is optional</source>
        <translation>Adresa je volitelná</translation>
    </message>
    <message>
        <location filename="../qml/pages/VenueAdd.qml" line="159"/>
        <source>VENUE CATEGORY</source>
        <translation>KATEGORIE</translation>
    </message>
    <message>
        <location filename="../qml/pages/VenueAdd.qml" line="164"/>
        <source>Not selected</source>
        <translation>Není vybrána</translation>
    </message>
    <message>
        <location filename="../qml/pages/VenueAdd.qml" line="165"/>
        <source>Tap to select category</source>
        <translation>Zvolte pro výběr kategorie</translation>
    </message>
    <message>
        <location filename="../qml/pages/VenueAdd.qml" line="172"/>
        <source>Venue categories are not loaded yet</source>
        <translation>Kategorie podniků nejsou dosud načtené</translation>
    </message>
    <message>
        <location filename="../qml/pages/VenueAdd.qml" line="182"/>
        <source>VENUE LOCATION</source>
        <translation>UMÍSTĚNÍ PODNIKU</translation>
    </message>
    <message>
        <location filename="../qml/pages/VenueAdd.qml" line="209"/>
        <source>CREATE VENUE</source>
        <translation>VYTVOŘIT PODNIK</translation>
    </message>
    <message>
        <location filename="../qml/pages/VenueAdd.qml" line="212"/>
        <source>You should specify venue name</source>
        <translation>Měli byste zadat jméno podniku</translation>
    </message>
    <message>
        <location filename="../qml/pages/VenueAdd.qml" line="216"/>
        <source>You should select category</source>
        <translation>Měli byste zadat kategorii</translation>
    </message>
    <message>
        <location filename="../qml/pages/VenueAdd.qml" line="220"/>
        <source>Can&apos;t get GPS position for venue</source>
        <translation>Nelze získat GPS pozici podniku</translation>
    </message>
</context>
<context>
    <name>VenueMap</name>
    <message>
        <location filename="../qml/pages/VenueMap.qml" line="213"/>
        <source>GET ROUTE</source>
        <translation>JAK SE TAM DOSTANU</translation>
    </message>
</context>
<context>
    <name>VenuesList</name>
    <message>
        <location filename="../qml/pages/VenuesList.qml" line="23"/>
        <source>NEARBY VENUES</source>
        <translation>BLÍZKÉ PODNIKY</translation>
    </message>
    <message>
        <location filename="../qml/pages/VenuesList.qml" line="38"/>
        <source>GPS signal is fuzzy, cannot get your location</source>
        <translation>GPS signál není nic moc, nelze vás najít</translation>
    </message>
    <message>
        <location filename="../qml/pages/VenuesList.qml" line="125"/>
        <source>Locking GPS, please wait</source>
        <translation>Získávám údaje GPS, vyčkejte</translation>
    </message>
    <message>
        <location filename="../qml/pages/VenuesList.qml" line="141"/>
        <source>Tap to search place...</source>
        <translation>Klikněte pro hledání místa...</translation>
    </message>
    <message>
        <location filename="../qml/pages/VenuesList.qml" line="157"/>
        <source>SEARCH</source>
        <translation>HLEDAT</translation>
    </message>
    <message>
        <location filename="../qml/pages/VenuesList.qml" line="198"/>
        <source>ADD NEW VENUE</source>
        <translation>PŘIDAT NOVÝ PODNIK</translation>
    </message>
</context>
<context>
    <name>Welcome</name>
    <message>
        <location filename="../qml/pages/Welcome.qml" line="29"/>
        <source>Welcome!</source>
        <translation>Vítejte!</translation>
    </message>
    <message>
        <location filename="../qml/pages/Welcome.qml" line="46"/>
        <source>Please, login with Foursquare!</source>
        <translation>Prosím, přihlašte se do Foursquare</translation>
    </message>
    <message>
        <location filename="../qml/pages/Welcome.qml" line="53"/>
        <source>Login</source>
        <translation>Přihlásit se</translation>
    </message>
    <message>
        <location filename="../qml/pages/Welcome.qml" line="67"/>
        <source>Foursquare privacy policy</source>
        <translation>Zásady ochrany soukromí Foursquare</translation>
    </message>
    <message>
        <location filename="../qml/pages/Welcome.qml" line="81"/>
        <source>Nelisquare privacy policy</source>
        <translation>Zásady ochrany soukromí Nelisquare</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../qml/main.qml" line="387"/>
        <source>Location data</source>
        <translation>Lokalizační data</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="388"/>
        <source>Nelisquare requires use of user location data. Data is needed to make geo-location services work properly.</source>
        <translation>Nelisquare vyžaduje použití lokalizačních dat uživatele. Tato data jsou potřebná pro správný chod lokalizačních funkcí.</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="389"/>
        <source>Allow</source>
        <translation>Povolit</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="390"/>
        <source>Deny</source>
        <translation>Zakázat</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="402"/>
        <source>Push notifications</source>
        <translation>Přímá upozornění</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="403"/>
        <source>Incoming push notifications are not supported at this version and are disabled by default.&lt;br/&gt;&lt;br/&gt;You will be promted again when they will be available at future versions.</source>
        <translation>Přímá příchozí upozornění nejsou podporována v této verzi a proto nejsou ve výchozím stavu povolena..&lt;br/&gt;&lt;br/&gt;Jakmile budou dostupná v nové verzi, oznámíme vám to.</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="407"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="124"/>
        <source>Check updates</source>
        <translation>Zkontrolovat nové verze</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="130"/>
        <source>Settings</source>
        <translation>Nastavení</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="136"/>
        <source>Exit</source>
        <translation>Ukončit</translation>
    </message>
</context>
</TS>